@@ -225,6 +225,14 @@ EnumMap = {
     'QAbstractSpinBox::AdaptiveDecimalStepType':    'QAbstractSpinBox::StepType::AdaptiveDecimalStepType',
     'QAbstractSpinBox::DefaultStepType':            'QAbstractSpinBox::StepType::DefaultStepType',
 
+    'QAction::NoRole':                  'QAction::MenuRole::NoRole',
+    'QAction::TextHeuristicRole':       'QAction::MenuRole::TextHeuristicRole',
+    'QAction::ApplicationSpecificRole': 'QAction::MenuRole::ApplicationSpecificRole',
+    'QAction::AboutQtRole':             'QAction::MenuRole::AboutQtRole',
+    'QAction::AboutRole':               'QAction::MenuRole::AboutRole',
+    'QAction::PreferencesRole':         'QAction::MenuRole::PreferencesRole',
+    'QAction::QuitRole':                'QAction::MenuRole::QuitRole',
+
     'QCalendarWidget::LongDayNames':            'QCalendarWidget::HorizontalHeaderFormat::LongDayNames',
     'QCalendarWidget::NoHorizontalHeader':      'QCalendarWidget::HorizontalHeaderFormat::NoHorizontalHeader',
     'QCalendarWidget::ShortDayNames':           'QCalendarWidget::HorizontalHeaderFormat::ShortDayNames',
@@ -326,6 +334,14 @@ EnumMap = {
     'QFontDatabase::Runic':                 'QFontDatabase::WritingSystem::Runic',
     'QFontDatabase::Nko':                   'QFontDatabase::WritingSystem::Nko',
 
+    'QFormLayout::AllNonFixedFieldsGrow':   'QFormLayout::FieldGrowthPolicy::AllNonFixedFieldsGrow',
+    'QFormLayout::ExpandingFieldsGrow':     'QFormLayout::FieldGrowthPolicy::ExpandingFieldsGrow',
+    'QFormLayout::FieldsStayAtSizeHint':    'QFormLayout::FieldGrowthPolicy::FieldsStayAtSizeHint',
+
+    'QFormLayout::DontWrapRows':    'QFormLayout::RowWrapPolicy::DontWrapRows',
+    'QFormLayout::WrapLongRows':    'QFormLayout::RowWrapPolicy::WrapLongRows',
+    'QFormLayout::WrapAllRows':     'QFormLayout::RowWrapPolicy::WrapAllRows',
+
     'QFrame::Box':          'QFrame::Shape::Box',
     'QFrame::HLine':        'QFrame::Shape::HLine',
     'QFrame::NoFrame':      'QFrame::Shape::NoFrame',
